## HEATY

### Author
Tom Christiaens @ [http://www.dirkchristiaens.be](http://www.dirkchristiaens.be)


### About
Heaty is a building heat load calculator that implements the "standard method" set 
out in the European standard EN 12831-1:2017 under chapter 6.


### Usage
Unzip and place the folder "heaty" containing the executable "heaty.exe" anywhere 
you want on your computer. Double click "heaty.exe" in the folder and you're launched. 
Further usage instructions can be found under the *Help* menu, under *User Guide*. 
The user guide is a PDF-document that will be opened in your standard PDF-reader.


### Notes
"Heaty" is developed with Python 3.8 on a Windows 10 computer.
